@@ -106,7 +106,9 @@ static void help(void)
     printf("    --debug                                 Enable debug mode\n");
     printf("    --log=FILE               -l FILE        Log into FILE\n");
     printf("    --config-file=FILE       -c FILE        Read configuration from FILE\n");
-    printf("    --fail-if-cvd-older-than=days           Return with a nonzero error code if virus database outdated.\n");
+    printf("    --fail-if-cvd-older-than=days           Return with a nonzero error code if virus database outdated\n");
+    printf("    --datadir=DIRECTORY                     Load signatures from DIRECTORY\n");
+    printf("    --pid=FILE               -p FILE        Write the daemon's pid to FILE\n");
     printf("\n");
     printf("Pass in - as the filename for stdin.\n");
     printf("\n");
@@ -466,6 +468,8 @@ int main(int argc, char **argv)
             break;
         }
 
+        if ((opt = optget(opts, "cache-size"))->enabled)
+            cl_engine_set_num(engine, CL_ENGINE_CACHE_SIZE, opt->numarg);
         if (optget(opts, "disable-cache")->enabled)
             cl_engine_set_num(engine, CL_ENGINE_DISABLE_CACHE, 1);
 
