@@ -205,12 +205,21 @@ static char *clamd_header       = NULL;
 static void resize(void)
 {
     char *p;
-    unsigned new_maxy, new_maxx;
+    int new_maxy, new_maxx;
+
     getmaxyx(stdscr, new_maxy, new_maxx);
-    if (new_maxy == maxy && new_maxx == maxx)
+    if (new_maxy == -1 || new_maxx == -1) {
+        fprintf(stderr, "Failed to get terminal size\n");
         return;
-    maxx = new_maxx;
-    maxy = new_maxy;
+    }
+
+    if ((unsigned int)new_maxy == maxy && (unsigned int)new_maxx == maxx) {
+        // no change
+        return;
+    }
+
+    maxx = (unsigned int)new_maxx;
+    maxy = (unsigned int)new_maxy;
     free(queue_header);
     free(clamd_header);
     queue_header = malloc(maxx + 1);
@@ -1341,14 +1350,14 @@ static void help(void)
     printf("           By The ClamAV Team: https://www.clamav.net/about.html#credits\n");
     printf("           (C) 2023 Cisco Systems, Inc.\n");
     printf("\n");
-    printf("    clamdtop [-hVc] [host[:port] /path/to/clamd.socket ...]\n");
+    printf("    clamdtop [-hVc] [host[:port] /path/to/clamd.sock ...]\n");
     printf("\n");
     printf("    --help                 -h         Show this help\n");
     printf("    --version              -V         Show version\n");
     printf("    --config-file=FILE     -c FILE    Read clamd's configuration files from FILE\n");
     printf("    --defaultcolors        -d         Use default terminal colors\n");
     printf("    host[:port]                       Connect to clamd on host at port (default 3310)\n");
-    printf("    /path/to/clamd.socket             Connect to clamd over a local socket\n");
+    printf("    /path/to/clamd.sock               Connect to clamd over a local socket\n");
     printf("\n");
     return;
 }
