@@ -1,8 +1,14 @@
 /*
- *  Copyright (C) 2007-2010 Sourcefire, Inc.
+ *  Copyright (C) 2013-2023 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Tomasz Kojm
  *
+ *  Summary: Code to parse Clamav CVD database format.
+ *
+ *  Acknowledgements: ClamAV untar code is based on a public domain minitar utility
+ *                    by Charles G. Waldman.
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
  *  published by the Free Software Foundation.
@@ -25,8 +31,6 @@
 #include <zlib.h>
 #include "clamav.h"
 
-#include "sha256.h"
-
 struct cli_dbio {
     gzFile gzs;
     FILE *fs;
@@ -34,10 +38,9 @@ struct cli_dbio {
     char *buf, *bufpt, *readpt;
     unsigned int usebuf, bufsize, readsize;
     unsigned int chkonly;
-    SHA256_CTX sha256ctx;
+    void *hashctx;
 };
 
-int cli_cvdload(FILE *fs, struct cl_engine *engine, unsigned int *signo, unsigned int options, unsigned int dbtype, const char *filename, unsigned int chkonly);
-int cli_cvdunpack(const char *file, const char *dir);
+cl_error_t cli_cvdload(FILE *fs, struct cl_engine *engine, unsigned int *signo, unsigned int options, unsigned int dbtype, const char *filename, unsigned int chkonly);
 
 #endif
