@@ -1,7 +1,7 @@
 /*
  *  Parse a regular expression, and extract a static suffix.
  *
- *  Copyright (C) 2013-2019 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2023 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Török Edvin
@@ -25,10 +25,23 @@
 #include "regex/regex.h"
 
 struct regex_list {
-	char *pattern;
-	regex_t *preg;
-	struct regex_list *nxt;
+    char *pattern;
+    regex_t *preg;
+    struct regex_list *nxt;
 };
-typedef int (*suffix_callback)(void *cbdata, const char *suffix, size_t len, const struct regex_list *regex);
-int cli_regex2suffix(const char *pattern, regex_t *preg, suffix_callback cb, void *cbdata);
+
+typedef cl_error_t (*suffix_callback)(void *cbdata, const char *suffix, size_t len, const struct regex_list *regex);
+
+/**
+ * @brief Build a suffix tree given a regex pattern
+ *
+ * @param pattern The regex pattern
+ * @param pregs
+ * @param cb
+ * @param cbdata
+ * @return cl_error_t May return a clam error type or may return a regex error integer.
+ *         TODO: separate regex error code from clam error code into out param.
+ */
+cl_error_t cli_regex2suffix(const char *pattern, regex_t *preg, suffix_callback cb, void *cbdata);
+
 #endif
