@@ -624,6 +624,9 @@ static unsigned int parse_local_file_header(
     uint32_t csize, usize;
     unsigned int size_of_fileheader_and_data = 0;
 
+    uint32_t nsize  = 0;
+    const char *src = NULL;
+
     if (!(local_header = fmap_need_off(map, loff, SIZEOF_LOCAL_HEADER))) {
         cli_dbgmsg("cli_unzip: local header - out of file\n");
         goto done;
@@ -647,18 +650,19 @@ static unsigned int parse_local_file_header(
         fmap_unneed_off(map, loff, SIZEOF_LOCAL_HEADER);
         goto done;
     }
-    if (ctx->engine->cdb || cli_debug_flag || ctx->engine->keeptmp || ctx->options->general & CL_SCAN_GENERAL_COLLECT_METADATA) {
-        uint32_t nsize = (LOCAL_HEADER_flen >= sizeof(name)) ? sizeof(name) - 1 : LOCAL_HEADER_flen;
-        const char *src;
-        if (nsize && (src = fmap_need_ptr_once(map, zip, nsize))) {
-            memcpy(name, zip, nsize);
-            name[nsize] = '\0';
-            if (CL_SUCCESS != cli_basename(name, nsize, &original_filename)) {
-                original_filename = NULL;
-            }
-        } else
-            name[0] = '\0';
+
+    nsize = (LOCAL_HEADER_flen >= sizeof(name)) ? sizeof(name) - 1 : LOCAL_HEADER_flen;
+    src   = fmap_need_ptr_once(map, zip, nsize);
+    if (nsize && (NULL != src)) {
+        memcpy(name, zip, nsize);
+        name[nsize] = '\0';
+        if (CL_SUCCESS != cli_basename(name, nsize, &original_filename)) {
+            original_filename = NULL;
+        }
+    } else {
+        name[0] = '\0';
     }
+
     zip += LOCAL_HEADER_flen;
     zsize -= LOCAL_HEADER_flen;
 
